#
# comment-inf.R, 18 Feb 21

# Data from:
# Commenting Source Code:
# Is It Worth It For Small Programming Tasks?

library("lme4")
library("plyr")


cinf=read.csv("comment-inf.csv", as.is=TRUE)

cnames=names(cinf)

t1_off=grep("t1", cnames)
a1_off=grep("a1", cnames)
o1_off=grep("o1", cnames)

# Some subjects performed in multiple groups
cinf$uid=1:nrow(cinf)

# We want to keep the associates tx/ax/ox values in the same row
cinf_wide=reshape(cinf, idvar="uid",
		  	varying=list(t1_off+(0:8), a1_off+(0:8), o1_off+(0:8)),
			v.names=c("t", "a", "o"),
			direction="long")

# Aspect      Task  Group
#                   A B C
# Apply code
#               1   N I D
#               2   I D N
#               3   D N I
# Fix bug
#               4   I D N
#               5   D N I
#               6   N I D
# Extend code
#               7   D N I
#               8   N I D
#               9   I D N

# Convert from a wide to a long format

rnames=row.names(cinf_wide)
cinf_wide$task=paste0("t", substring(rnames, nchar(rnames)))
cinf_wide$tnum=as.numeric(substring(rnames, nchar(rnames)))

aspect=c("Apply code", "Fix bug", "Extend code")

cinf_wide$aspect=aspect[1+(cinf_wide$tnum-1) / 3]
# table(cinf_wide$aspect, cinf_wide$tnum)

com_kind=matrix(data=c("N", "I", "D", "I", "D", "N", "D", "N", "I",
		       "I", "D", "N", "D", "N", "I", "N", "I", "D",
		       "D", "N", "I", "N", "I", "D", "I", "D", "N"),
		nrow=9, ncol=3)

cinf_wide$gnum=as.numeric(mapvalues(cinf_wide$group, c("A", "B", "C"), 1:3))
cinf_wide$com_kind=com_kind[cbind(cinf_wide$tnum, cinf_wide$gnum)]

# Box standard regression model
com_mod=glm(t ~ aspect
	    	+aspect:com_kind
		# +group
	    	# +a
		# +as.factor(o)
		+qExp_Years
		+tnum
	    	+task
		, data=cinf_wide)
summary(com_mod)


# But it really needs to be modled using mixed-effects
# id is only unique within each group.  Need to use uid
com_memod=lmer(t ~ aspect
	    	+com_kind
		# +group
	    	# +a
		# +as.factor(o)
		# +tnum
	    	+task
		+qExp_Years
		+(aspect | uid)
		, data=cinf_wide)
summary(com_memod)


